/**
 * Circle
 * 
 * This is GPL'd code
 * (c) by Patrick Kilian 2003
 *
 * Eine Klasse, die die x- und y- Koordinate des Mittelpunkt und den Radius
 * eines Kreises speichert.
 * Achtung es findet _keine_ Fehlerbehandlung statt.
 *
 * @author Patrick Kilian
 * @version 0.01
 */
public class Circle implements Figure{
    // x-Koordinate des Mittelpunktes
    private double x_koord = 0;
    // y-Koordinate des Mittelpunktes
    private double y_koord = 0;
    // Der nicht negative Radius
    private double radius = 0;
    /**
     * Konstruktor der Klasse Circle.
     * @param x x-Koordinate des Mittelpunktes
     * @param y y-Koordinate des Mittelpunktes
     * @param r der Radius darf nicht negativ sein
     */
    public Circle(double x, double y, double r) {
        x_koord = x;
        y_koord = y;
        if ( r >= 0 ) {
            radius = r;
        }
    }
    /**
     * Berechnet die Flche des Kreises
     * @return Die Flche des Kreises
     */
    public double area() {
        return (Math.PI * radius * radius);
    }
    /**
     * Berechnet den Unfang des Kreises
     * @return der Umfang des Kreises
     */
    public double circumference() {
        return (Math.PI * radius * 2);
    }
    /**
     * Testet, ob der Kreis den Punkt mit den angegebenen Koordinaten
     * berdeckt.
     * @param x Die x-Koordinate des zu berprfenden Punktes
     * @param y Die y-Koordinate des zu berprfenden Punktes
     * @return true wenn der Punkt im Kreis liegt ansonst false.
     */
    public boolean overlaps(double x, double y) {
        double dist = 0;
        dist = Math.pow((x_koord - x), 2);
        dist += Math.pow((y_koord - y), 2);
        dist = Math.pow(dist, 0.5);
        if (dist <= radius) {
            return (true);
        } else {
            return (false);
        }
    }
    /**
     * Gibt eine Stringdarstellung des Kreises aus
     * @return String der den Kreis beschreibt
     */
    public String toString() {
        String out = new String("Circle(");
        out += x_koord;
        out += ",";
        out += y_koord;
        out += ",";
        out += radius;
        out += ")";
        return (out);
    }
}
