/**
 * Rectangle
 * 
 * This is GPL'd code
 * (c) by Patrick Kilian 2003
 *
 * Eine Klasse, die die x- und y- Koordinaten von zwei Punkten, die ein
 * achesenparalleles Rechteck aufspannen, speichert
 * Achtung es findet _keine_ Fehlerbehandlung statt.
 *
 * @author Patrick Kilian
 * @version 0.01
 */
public class Rectangle implements Figure{
    // x-Koordinate des linken unteren Punktes
    private double x_koord_1 = 0;
    // x-Koordinate des rechten oberen Punktes
    private double x_koord_2 = 0;
    // y-Koordinate des linken unteren Punktes
    private double y_koord_1 = 0;
    // y-Koordinate des rechten oberen Punktes
    private double y_koord_2 = 0;
    /**
     * Konstruktor der Klasse Rectangle
     * @param xLowerLeft x-Koordinate eines Punktes
     * @param yLowerLeft y-Koordinate eines Punktes
     * @param width Breite des Rechteckes
     * @param height Hhe des Rechteckes
     */
    public Rectangle(double xLowerLeft, double yLowerLeft,
                     double width, double height) {
        double temp = 0;
        x_koord_1 = xLowerLeft;
        y_koord_1 = yLowerLeft;
        x_koord_2 = xLowerLeft + width;
        y_koord_2 = yLowerLeft + height;
        if (x_koord_2 < x_koord_1) {
            temp = x_koord_2; 
            x_koord_2 = x_koord_1;
            x_koord_1 = temp;
        }
        if (y_koord_2 < y_koord_1) {
            temp = y_koord_2; 
            y_koord_2 = y_koord_1;
            y_koord_1 = temp;
        }
    }
    /**
     * Berechnet die Flche des Rechtecks
     * @return Die Flche des Rechtecks
     */
    public double area() {
        return ((x_koord_2 - x_koord_1) * (y_koord_2 - y_koord_1));
    }
    /**
     * Berechnet dem Unfang des Rechtecks
     * @return der Umfang des Rechtecks
     */
    public double circumference() {
        return ( 2 * ((x_koord_2 - x_koord_1) + (y_koord_2 - y_koord_1)));
    }
    /**
     * Testet, ob das Rechteck den Punkt mit den angegebenen Koordinaten
     * berdeckt.
     * @param x Die x-Koordinate des zu berprfenden Punktes
     * @param y Die y-Koordinate des zu berprfenden Punktes
     * @return true wenn der Punkt im Rechteck liegt ansonst false.
     */
    public boolean overlaps(double x, double y) {
        if ((x_koord_1 <= x) && (x <= x_koord_2) &&
            (y_koord_1 <= y) && (y <= y_koord_2)) {
            return (true);
        } else {
            return (false);
        }
    }
    /**
     * Gibt eine Stringdarstellung des Rechteckes aus
     * @return String der das Rechteck beschreibt
     */
    public String toString() {
        String out = new String("Rectangle(");
        out += x_koord_1;
        out += ",";
        out += y_koord_1;
        out += ",";
        out += x_koord_2;
        out += ",";
        out += y_koord_2;
        out += ")";
        return (out);
    }
}
